<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "fbth";

$theme_dir = get_template_directory_uri();

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('redux_demo/opt_name', $opt_name);

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */

$sampleHTML = '';

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'dev_mode'             => false,
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    // 'display_name'         => $theme->get( 'Name' ),
    'display_name'         => esc_html__('Theme Settings', 'fbth'),
    // Name that appears at the top of your panel
    // 'display_version'      => $theme->get( 'Version' ),
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Settings', 'fbth'),
    'page_title'           => esc_html__('Theme Settings', 'fbth'),
    // You will need to generate a Google API key to use this feature.
    'page_slug'            => 'FinestCoreOptions',
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => 'AIzaSyAs5fBAvB5HKK05nz5zhb1eWFziECHEz6o',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Show the time the page took to load, etc
    'update_notice'        => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => false,
    // Enable basic customizer support
    // 'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => 2,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => get_theme_file_uri('/assets/images/theme-options/theme-option.png"'),
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => false,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
);

// Add content after the form.
$args['footer_text'] = sprintf('<p>%s</p>', esc_html__('This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.', 'fbth'));

Redux::setArgs($opt_name, $args);

/*
 * ---> END ARGUMENTS
 */

/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id'      => 'redux-help-tab-1',
        'title'   => esc_html__('Theme Information 1', 'fbth'),
        'content' => '<p>' . esc_html__('This is the tab content, HTML is allowed.', 'fbth') . '</p>',
    ),
    array(
        'id'      => 'redux-help-tab-2',
        'title'   => esc_html__('Theme Information 2', 'fbth'),
        'content' => '<p>' . esc_html__('This is the tab content, HTML is allowed.', 'fbth') . '</p>',
    ),
);
Redux::set_help_tab($opt_name, $tabs);

// Set the help sidebar
$content = '<p>' . esc_html__('This is the sidebar content, HTML is allowed.', 'fbth') . '</p>';
Redux::set_help_sidebar($opt_name, $content);

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/branding.png"'),
    'icon_type'        => 'image',
    'title'            => esc_html__('Branding', 'fbth'),
    'id'               => 'logo_settings',
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'       => 'primary_logo',
            'type'     => 'media',
            'title'    => esc_html__('Primary Logo', 'fbth'),
            'subtitle' => '<p>Use a logo which will be used on white background. </p>
           <p> Recommended size: 125 x 40 | PNG, SVG</p>',
            'default'  => array(
                'url' => 'https://redindex.net/demos/wp/crito/wp-content/uploads/2023/08/logo-black.png',
            ),
        ),
        array(
            'id'       => 'secondary_logo',
            'type'     => 'media',
            'title'    => esc_html__('Dark Version Logo', 'fbth'),
            'subtitle' => '<p>Use a logo which will be used on dark background. </p>
            <p> Recommended size: 125 x 40 | PNG, SVG</p>',
            'default'  => array(
                'url' => 'https://redindex.net/demos/wp/crito/wp-content/uploads/2023/10/logo-white.png',
            ),
        ),
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'title'    => esc_html__('Favicon', 'fbth'),
            'subtitle' => esc_html__('Choose the favicon', 'fbth'),
            'default'  => array(
                'url' => 'https://redindex.net/demos/wp/crito/wp-content/uploads/2023/08/favicon.png',
            ),
        ),

        array(
            'id'      => 'enable_preloader',
            'type'    => 'switch',
            'title'   => esc_html__('Enable Preloader?', 'fbth'),
            'desc'    => esc_html__('Wish to use preloader?', 'fbth'),
            'default' => true,
        ),
        array(
            'id'       => 'preloader_style',
            'type'     => 'select',
            'title'    => esc_html__('Preloader Style', 'fbth'),
            'desc'     => esc_html__('Select a predefined preloader style.', 'fbth'),
            'placeholder' => __('Select a style', 'fbth'),
            'options'  => array(
                'default' => esc_html__('Default', 'fbth'),
                'style-1' => esc_html__('Style 1', 'fbth'),
                'style-2' => esc_html__('Style 2', 'fbth'),
                'custom'  => esc_html__('Custom', 'fbth'),
            ),
            'default'  => 'default',
            'required' => array('enable_preloader', '=', true),
        ),
        array(
            'id'       => 'preloader_image',
            'type'     => 'media',
            'title'    => esc_html__('Preloader image', 'fbth'),
            'subtitle' => esc_html__('Choose the site preloader', 'fbth'),
            'required' => array('preloader_style', '=', 'custom'),

        ),
    ),
));

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/brand-typography.png"'),
    'icon_type'        => 'image',

    'title'            => esc_html__('Typography', 'fbth'),
    'id'               => 'typography',
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'             => 'h1_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H1', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 1 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'font-weight'    => '700',
                'google'         => true,
                "font-size"      => "96px",
                "line-height"    => "100px",
                "letter-spacing" => "-1.92px",
                "font-color"     => "#191919",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'text-align'     => false,
            'units'          => 'px',
        ),

        array(
            'id'             => 'h2_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H2', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 2 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'google'         => true,
                'font-weight'    => '700',
                "font-size"      => "45px",
                "line-height"    => "54px",
                "letter-spacing" => "0px",
                "font-color"     => "#191919",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'text-align'     => false,
            'color'          => true,
            'units'          => 'px',
        ),

        array(
            'id'             => 'h3_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H3', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 3 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'font-weight'    => '600',
                'google'         => true,
                "font-size"      => "40px",
                "line-height"    => "48px",
                "letter-spacing" => "-0.8px",
                "font-color"     => "#111",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'units'          => 'px',
        ),

        array(
            'id'             => 'h4_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H4', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 4 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'font-weight'    => '700',
                'google'         => true,
                "font-size"      => "22px",
                "line-height"    => "33px",
                "letter-spacing" => "0px",
                "font-color"     => "#191919",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'units'          => 'px',
        ),

        array(
            'id'             => 'h5_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H5', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 5 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'font-weight'    => '600',
                'google'         => true,
                "font-size"      => "24px",
                "line-height"    => "34px",
                "letter-spacing" => "-0.5",
                "font-color"     => "#0C1E1B",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'units'          => 'px',
        ),

        array(
            'id'             => 'h6_typography',
            'type'           => 'typography',
            'title'          => esc_html__('H6', 'fbth'),
            'subtitle'       => esc_html__('Set Heading 6 options.', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'DM Sans',
                'font-weight'    => '500',
                'google'         => true,
                "font-size"      => "18px",
                "line-height"    => "22px",
                "letter-spacing" => "-0.18",
                "font-color"     => "#F94D1C;",
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'units'          => 'px',
        ),

        array(
            'id'             => 'body_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body Default', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "18px",
                "line-height"    => "30px",
                "letter-spacing" => "0px",
                "font-color"     => "#4A5957",
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('body'),
            'units'          => 'px',
        ),

        array(
            'id'             => 'body_extra_extra_large_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body XXL', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "20px",
                "line-height"    => "34px",
                "letter-spacing" => "0px",
                "font-color"     => "#4A5957"
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('div.elementor-widget-heading .elementor-heading-title.elementor-size-xxl', 'div.elementor-widget-container .fbth-size-xxl, body div.elementor-widget.fbth-size-xxl p'),
            'units'          => 'px',
        ),
        array(
            'id'             => 'body_extra_large_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body XL', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "16px",
                "line-height"    => "24px",
                "letter-spacing" => "",
                "font-color"     => "#000000",
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('div.elementor-widget-heading .elementor-heading-title.elementor-size-xl', 'div.elementor-widget-container .fbth-size-xl, body div.elementor-widget.fbth-size-xl p'),
            'units'          => 'px',
        ),
        array(
            'id'             => 'body_large_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body Large', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "18px",
                "line-height"    => "27px",
                "letter-spacing" => "",
                "font-color"     => "#4A5957",
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('div.elementor-widget-heading .elementor-heading-title.elementor-size-large', 'div.elementor-widget-container .fbth-size-large, body div.elementor-widget.fbth-size-large p'),
            'units'          => 'px',
        ),
        array(
            'id'             => 'body_medium_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body Medium', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "16px",
                "line-height"    => "28px",
                "letter-spacing" => "0px",
                "font-color"     => "#4A5957",
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('div.elementor-widget-heading .elementor-heading-title.elementor-size-medium', '.fbth-size-medium'),
            'units'          => 'px',
        ),
        array(
            'id'             => 'body_small_typography',
            'type'           => 'typography',
            'title'          => esc_html__('Body Small', 'fbth'),
            'subtitle'       => esc_html__('Set <body> and <p> options.
            .', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family'    => 'Inter',
                'font-weight'    => '400',
                'google'         => true,
                "font-size"      => "14px",
                "line-height"    => "22px",
                "letter-spacing" => "",
                "font-color"     => "#4A5957",
            ),
            "fonts"          => array(
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'text-align'     => false,
            'line-height'    => true,
            'letter-spacing' => true,
            'text-transform' => true,
            'font-size'      => true,
            'color'          => true,
            'output'         => array('div.elementor-widget-heading .elementor-heading-title.elementor-size-small', 'div.elementor-widget-container .fbth-size-small, body div.elementor-widget.fbth-size-small p'),
            'units'          => 'px',
        ),

    ),
));

Redux::set_section(
    $opt_name,
    array(
        'icon'             => get_theme_file_uri('/assets/images/theme-options/brand-color.png"'),
        'icon_type'        => 'image',
        'title'            => esc_html__('Brand Colors', 'fbth'),
        'id'               => 'global_colors',
        'class'            => 'option-page-layout',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'       => 'primary_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Primary Color', 'fbth'),
                'subtitle' => esc_html__('Pick a color for the theme.', 'fbth'),
                'default'  => array(
                    'color' => '#f9d783',
                    'alpha' => 1,
                ),
            ),
            array(
                'id'       => 'secondary_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Secondary Color', 'fbth'),
                'subtitle' => esc_html__('Pick a color for the theme.', 'fbth'),
                'default'  => array(
                    'color' => '#f94d1c',
                    'alpha' => 1,
                ),

            ),
            array(
                'id'       => 'accent_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Accent Color', 'fbth'),
                'subtitle' => esc_html__('Pick a color for the theme.', 'fbth'),
                'default'  => array(
                    'color' => '#f94d1c',
                    'alpha' => 1,
                ),

            ),
            array(
                'id'       => 'heading_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Heading Color', 'fbth'),
                'subtitle' => esc_html__('Pick a color for headings.', 'fbth'),
                'default'  => array(
                    'color' => '#191919',
                    'alpha' => 1,
                ),

            ),
            array(
                'id'       => 'body_color',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Body Color', 'fbth'),
                'subtitle' => esc_html__('Pick a color for body texts.', 'fbth'),
                'default'  => array(
                    'color' => '#5e5e5e',

                ),

            ),
            array(
                'id'       => 'dark_bg',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Dark Background', 'fbth'),
                'subtitle' => esc_html__('Pick a color for dark background.', 'fbth'),
                'default'  => array(
                    'color' => '#0F151C',
                ),

            ),
            array(
                'id'       => 'light_bg',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Light Background', 'fbth'),
                'subtitle' => esc_html__('Pick a color for light background.', 'fbth'),
                'default'  => array(
                    'color' => '#F0EFE9',
                ),

            ),
            array(
                'id'       => 'white_bg',
                'type'     => 'color_rgba',
                'title'    => esc_html__('White Background', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#ffffff',
                ),
            ),

            array(
                'id'       => 'neutral_1',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 01', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#ffffff',
                ),
            ),
            array(
                'id'       => 'neutral_2',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 02', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#111111',
                ),
            ),
            array(
                'id'       => 'neutral_3',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 03', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#111',
                ),
            ),
            array(
                'id'       => 'neutral_4',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 04', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#353535',
                ),
            ),
            array(
                'id'       => 'neutral_5',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 05', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#12141D',
                ),
            ),
            array(
                'id'       => 'neutral_6',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 06', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#12141d',
                ),
            ),
            array(
                'id'       => 'neutral_7',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Neutral 07', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#0C1E1B',
                ),
            ),
            array(
                'id'       => 'success',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Success', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#38B27A',
                ),
            ),
            array(
                'id'       => 'warning',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Warning', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#FCD554',
                ),
            ),
            array(
                'id'       => 'info',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Info', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#4255F9',
                ),
            ),
            array(
                'id'       => 'danger',
                'type'     => 'color_rgba',
                'title'    => esc_html__('Danger', 'fbth'),
                'subtitle' => esc_html__('Pick a color for white background.', 'fbth'),
                'default'  => array(
                    'color' => '#EE2626',
                ),
            ),
        ),
    )
);

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/brand-typography.png"'),
    'icon_type'        => 'image',
    'title'            => esc_html__('Global Fonts', 'fbth'),
    'id'               => 'global_fonts',
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'             => 'primary_fonts',
            'type'           => 'typography',
            'title'          => esc_html__('Primary Fonts', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family' => 'DM Sans',
                // 'font-weight' => '400',
                'google'      => true,
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => false,
            'letter-spacing' => false,
            'text-align'     => false,
            'font-size'      => false,
            'color'          => false,
            'output'         => array('body'),
            'units'          => 'px',
            'subtitle'       => esc_html__('Set fonts for headings', 'fbth'),
        ),
        array(
            'id'             => 'secondary_fonts',
            'type'           => 'typography',
            'title'          => esc_html__('Secondary Fonts', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family' => 'DM Sans',
                // 'font-weight' => '400',
                'google'      => true,
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => false,
            'letter-spacing' => false,
            'text-align'     => false,
            'font-size'      => false,
            'color'          => false,
            'output'         => array('body'),
            'units'          => 'px',
            'subtitle'       => esc_html__('Set fonts for secondary headings', 'fbth'),
        ),
        array(
            'id'             => 'text_fonts',
            'type'           => 'typography',
            'title'          => esc_html__('Text Fonts', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family' => 'DM Sans',
                // 'font-weight' => '400',
                'google'      => true,
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => false,
            'letter-spacing' => false,
            'text-align'     => false,
            'font-size'      => false,
            'color'          => false,
            'output'         => array('body'),
            'units'          => 'px',
            'subtitle'       => esc_html__('Set fonts for text', 'fbth'),
        ),
        array(
            'id'             => 'accent_fonts',
            'type'           => 'typography',
            'title'          => esc_html__('Accent Fonts', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family' => 'DM Sans',
                // 'font-weight' => '400',
                'google'      => true,
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => false,
            'letter-spacing' => false,
            'text-align'     => false,
            'font-size'      => false,
            'color'          => false,
            'output'         => array('body'),
            'units'          => 'px',
            'subtitle'       => esc_html__('Set fonts for accent', 'fbth'),
        ),

    ),
));

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/header.png"'),
    'icon_type'        => 'image',

    'title'            => esc_html__('Header', 'fbth'),
    'id'               => 'header_settings',
    'customizer_width' => '450px',
    'fields'           => array(
        array(
            'id'      => 'enable_sticky_header',
            'type'    => 'switch',
            'title'   => esc_html__('Enable Sticky Header?', 'fbth'),
            'desc'    => esc_html__('Wish to enable sticky header?', 'fbth'),
            'default' => false,
        ),
        array(
            'id'       => 'sticky_background_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background color', 'fbth'),
            'subtitle' => esc_html__('Pick a color for the sticky header.', 'fbth'),
            'default'  => array(
                'color' => '#fff',
                'alpha' => 1,
            ),

            'required' => array('enable_sticky_header', '=', true),
        ),
        array(
            'id'       => 'sticky_menu_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Menu color', 'fbth'),
            'subtitle' => esc_html__('Change color of the menu when it’s on sticky.', 'fbth'),
            'default'  => array(
                'color' => '',
                'alpha' => 1,
            ),

            'required' => array('enable_sticky_header', '=', true),
        ),
        array(
            'id'       => 'enable_sticky_shadow',
            'type'     => 'switch',
            'title'    => esc_html__('Show shadow?', 'fbth'),
            'desc'     => esc_html__('Wish to show shadow in sticky header?', 'fbth'),
            'default'  => true,
            'required' => array('enable_sticky_header', '=', true),
        ),
        array(
            'id'       => 'sticky_mobile',
            'type'     => 'switch',
            'title'    => esc_html__('Sticky in mobile?', 'fbth'),
            'desc'     => esc_html__('Wish to show shadow in sticky header?', 'fbth'),
            'default'  => false,
            'required' => array('enable_sticky_header', '=', true),
        ),
    ),
));

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/blog.png"'),
    'icon_type'        => 'image',

    'title'            => esc_html__('Blog', 'fbth'),
    'id'               => 'blog_settings',
    'customizer_width' => '450px',
    'subsection'       => false,
    'fields'           => array(
        array(
            'id'       => 'blog_page_title',
            'type'     => 'text',
            'title'    => __('Blog Page Tilte', 'fbth'),
            'default'  => 'Welcome To Our Blog'
        ),
        array(
            'id' => 'blog_page_subtitle',
            'type' => 'textarea',
            'title' => __('Blog Page SubTitle', 'fbth'),
            'default' => 'Read latest news from our blog & learn new things.',

        ),
        array(
            'id'       => 'blog_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Blog Layout', 'fbth'),
            'subtitle' => esc_html__('Choose the layout you want in blog pages', 'fbth'),
            'options'  => array(
                'no_sidebar'    => get_theme_file_uri('/assets/images/layouts/fullpage.png"'),
                'left_sidebar'  => get_theme_file_uri('/assets/images/layouts/left-sidebar.png"'),
                'right_sidebar' => get_theme_file_uri('/assets/images/layouts/right-sidebar.png"'),
            ),
            'default'  => 'right_sidebar',
        ),
        array(
            'id'       => 'blog_grid',
            'type'     => 'image_select',
            'title'    => esc_html__('Blog Grid', 'fbth'),
            'subtitle' => esc_html__('Choose the number of column you want in blog pages', 'fbth'),
            'options'  => array(
                'one-column'   => get_theme_file_uri('/assets/images/layouts/1-col.png"'),
                'two-column'   => get_theme_file_uri('/assets/images/layouts/2-col.png"'),
                'three-column' => get_theme_file_uri('/assets/images/layouts/3-col.png"'),
            ),
            'default'  => 'two-column',
        ),

        array(
            'id'             => 'post_title_style',
            'type'           => 'typography',
            'title'          => esc_html__('Post Title Style', 'fbth'),
            'google'         => true,
            'font-backup'    => false,
            'subsets'        => false,
            'default'        => array(
                'font-family' => 'DM Sans',
                'font-weight' => '400',
                'google'      => true,
            ),
            "fonts"          => array(
                "DM Sans" => "DM Sans",
                "Inter"      => "Inter",
                "Roboto"       => "Roboto",
            ),
            'line-height'    => true,
            'letter-spacing' => true,
            'text-align'     => false,
            'font-size'      => true,
            'color'          => true,
            'units'          => 'px',
            'subtitle'       => esc_html__('Set fonts for post title', 'fbth'),
            'output'         => array('.fbth-blog-title a'),

        ),
        array(
            'id'      => 'show_excerpt',
            'type'    => 'switch',
            'title'   => __('Show Excerpt?', 'fbth'),
            'default' => true,
        ),
        array(
            'id'      => 'show_readmore',
            'type'    => 'switch',
            'title'   => __('Show Readmore?', 'fbth'),
            'default' => true,
        ),
        array(
            'id'      => 'show_date',
            'type'    => 'switch',
            'title'   => __('Show Date?', 'fbth'),
            'default' => true,
        ),
        array(
            'id'      => 'show_category',
            'type'    => 'switch',
            'title'   => __('Show Category?', 'fbth'),
            'default' => true,
        ),
        array(
            'id'      => 'show_bradecamp',
            'type'    => 'switch',
            'title'   => __('Show Bradecamp?', 'fbth'),
            'default' => true,
        ),

        array(
            'id'       => 'posts_per_page',
            'type'     => 'text',
            'title'    => esc_html__('Blog Post to Show', 'fbth'),
            'subtitle' => esc_html__('Set the number of posts displayed on a page.', 'fbth'),
            'default'  => 4,
            'validate' => 'numeric',
        ),

    ),
));

Redux::set_section($opt_name, array(
    'title'            => esc_html__('Single Page', 'fbth'),
    'id'               => 'single_page_settings',
    'customizer_width' => '450px',
    'subsection'       => true,
    'fields'           => array(
        array(
            'id'       => 'single_page_layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Single Page Layout', 'fbth'),
            'subtitle' => esc_html__('Choose the layout you want in single pages', 'fbth'),
            'options'  => array(
                'no_sidebar'    => get_theme_file_uri('/assets/images/layouts/fullpage.png"'),
                'left_sidebar'  => get_theme_file_uri('/assets/images/layouts/left-sidebar.png"'),
                'right_sidebar' => get_theme_file_uri('/assets/images/layouts/right-sidebar.png"'),
            ),
            'default'  => 'right_sidebar',
        ),

        array(
            'id'      => 'show_post_navigation',
            'type'    => 'switch',
            'title'   => __('Show Post Navigation?', 'fbth'),
            'default' => true,
        ),
    ),
));

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/integrations.png"'),
    'icon_type'        => 'image',

    'title'            => esc_html__('Integrations', 'fbth'),
    'id'               => 'fbth_integrations',
    'customizer_width' => '450px',
    'subsection'       => false,
    'fields'           => array(
        array(
            'id'       => 'gmap_api',
            'type'     => 'text',
            'title'    => esc_html__('Google Maps Api', 'fbth'),
            'subtitle' => esc_html__('Set the google map api.', 'fbth'),
            'default'  => esc_html__('1', 'fbth'),
        ),
    ),
));

Redux::set_section(
    $opt_name,
    array(
        'icon'             => get_theme_file_uri('/assets/images/theme-options/general.png"'),
        'icon_type'        => 'image',

        'title'            => esc_html__('404 Page', 'fbth'),
        'id'               => '404_settings',
        'class'            => 'option-page-layout',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'          => '404_section',
                'type'        => 'select',
                'title'       => esc_html__('404 Page', 'fbth'),
                'placeholder' => __('Select a page', 'fbth'),
                'desc'        => esc_html__('Select a custom 404 page to overwrite the default one.', 'fbth'),
                'data'        => 'posts',
                'args'        => array(
                    'post_type'      => 'page',
                    'posts_per_page' => -1,
                    'orderby'        => 'title',
                    'order'          => 'ASC',
                ),
            ),

        ),
    )
);

Redux::set_section($opt_name, array(
    'icon'             => get_theme_file_uri('/assets/images/theme-options/code.png"'),
    'icon_type'        => 'image',
    'title'            => esc_html__('Custom Code', 'fbth'),
    'id'               => 'custom_section',
    'customizer_width' => '400px',
    'fields'           => array(

        array(
            'id'       => 'scustom_css',
            'type'     => 'ace_editor',
            'title'    => __('CSS Code', 'fbth'),
            'subtitle' => __('Paste your CSS code here.', 'fbth'),
            'mode'     => 'css',
            'theme'    => 'monokai',
            'desc'     => 'Possible modes can be found at <a href="' . 'http://' . 'ace.c9.io" target="_blank">' . 'http://' . 'ace.c9.io/</a>.',
            'default'  => " /** #header{\n   margin: 0 auto;\n }**/",
        ),
        array(
            'id'       => 'scustom_js',
            'type'     => 'ace_editor',
            'title'    => __('JavaScript Code', 'fbth'),
            'subtitle' => __('Paste your JavaScript code here.', 'fbth'),
            'mode'     => 'javascript',
            'theme'    => 'monokai',
            'desc'     => 'Possible modes can be found at <a href="' . 'http://' . 'ace.c9.io" target="_blank">' . 'http://' . 'ace.c9.io/</a>.',
            'default'  => " /** #header{\n   margin: 0 auto;\n }**/",
        ),

    ),
));

/*
 * <--- END SECTIONS
 */
function fbth_add_demo_link()
{
    $import_url = admin_url('themes.php?page=one-click-demo-import');

    $tala_url = admin_url('admin.php?page=fbth-activation');
//     echo '<li class="fbth-tala-link"><a href="' . esc_url($tala_url) . '" class="redux-group-tab-link-a" style="color:#ffd700de!important"> <img src="' . get_theme_file_uri('/assets/images/theme-options/tala.png"') . '"/> <span class="group_title">' . esc_html__('Theme Activation', 'fbth') . '</span></a></li>';
    echo '<li class=""><a href="' . esc_url($import_url) . '" class="redux-group-tab-link-a"> <img src="' . get_theme_file_uri('/assets/images/theme-options/demo-setup.png"') . '"/> <span class="group_title">' . esc_html__('Demo Setup', 'fbth') . '</span></a></li>';
}
add_action('redux/page/fbth/menu/after', 'fbth_add_demo_link');

/**
 * Modify the favicon URL used by the Customizer.
 *
 * @param string $url The default favicon URL.
 * @return string The modified favicon URL.
 */
function fbth_favicon_url()
{

    $fbth = get_option('fbth');
    // Check if the $fbth option exists and the favicon array key is set.
    if (isset($fbth['favicon']) && isset($fbth['favicon']['id']) && !empty($fbth['favicon']['id'])) {
        update_option('site_icon', $fbth['favicon']['id']);
    }
}
add_action('init', 'fbth_favicon_url');
